import os

from flask import Flask


def create_app(test_config=None):
    # create and configure the app
    app = Flask(__name__, instance_relative_config=True)
    app.config.from_mapping(
        SECRET_KEY='dev'
    )

    if test_config is None:
        # load the instance config, if it exists, when not testing
        app.config.from_pyfile('config.py', silent=True)
    else:
        # load the test config if passed in
        app.config.from_mapping(test_config)

    # ensure the instance folder exists
    try:
        os.makedirs(app.instance_path)
    except OSError:
        pass

    # will later become the homepage
    @app.get('/')
    def homepage():
        return 'Welcome to GarganTools'

    # a simple page that says hello
    @app.get('/hello')
    def hello():
        return 'Hello, World!'

    from .src import contexts
    from .src import terms

    app.register_blueprint(contexts.bp)

    app.register_blueprint(terms.bp)

    return app
