import json
from flask import Blueprint, request

from gargantools.utils.contexts_utils import check_fileContent
from gargantools.utils.utils import check_columnName, check_fileExtension, check_fileEncoding, get_fileContent, get_fileDelimiter


COLUMN_NAMES = ["Publication Day", "Publication Month", "Publication Year", "Authors", "Title", "Abstract", "Source"]

bp = Blueprint("contexts", __name__, url_prefix="/contexts")

@bp.get('')
def tsvTemplate():
    return json.dumps({"Publication Day": 1, "Publication Month": 1, "Publication Year": 1, "Authors": "Some authors", "Title": "A title", "Abstract": "An abstract", "Source": "Some Source" }, indent=3)

@bp.post('')
def tsvValidation():
    if 'file' not in request.files:
        return "Bad request, missing file\n", 400
    else:
        file = request.files['file']
        if not (file and check_fileExtension(file.filename, {"csv", "tsv"})):
            return "Incorrect file format or file format not found\n", 400
        else:
            file_encoding = check_fileEncoding(file)
            if file_encoding is None:
                return "Could not read the file\n", 422
            elif get_fileDelimiter(file, file_encoding) != '\t':
                return "File delimiter not found or Incorrect file delimiter, should be a tabulation\n", 422
            else:
                file_content = get_fileContent(file, '\t')
                if file_content is None:
                    print('here')
                    return "Could not read the file\n", 422
                else:
                    header = file_content.keys()
                    state, notFoundColumn = check_columnName(header, COLUMN_NAMES)
                    if not state:
                        return f"Some column names were not found {','.join(notFoundColumn)}\n", 422
                    else:
                        state, problems = check_fileContent(file_content)
                        if state:
                            return "Correct file\n", 200
                        else:
                            if problems is not None:
                                return 'Incorrect file - File is not compatible with GarganText\n', 422
                            else:
                                return 'Unexpected error in file\n', 422
                