import json
from flask import Blueprint, request

from gargantools.utils.terms_utils import check_fileContent
from gargantools.utils.utils import check_columnName, check_fileEncoding, check_fileExtension, get_fileContent, get_fileDelimiter

COLUMN_NAMES = ["status", "label"]

bp = Blueprint("terms", __name__, url_prefix="/terms")

@bp.get('')
def termsTemplate():
    return json.dumps({"status": "MapTerm", "label": "A term"}, indent=3)

@bp.post('')
def termsValidation():
    if 'file' not in request.files:
        return "Bad request, missing file\n", 400
    else:
        file = request.files['file']
        if not (file and check_fileExtension(file.filename, {"csv", "tsv"})):
            return "Incorrect file format or file format not found\n", 400
        else:
            file_encoding = check_fileEncoding(file)
            if file_encoding is None:
                return "Could not read the file\n", 422
            elif get_fileDelimiter(file, file_encoding) != '\t':
                return "Error while getting file delimiter.\n Can be the following : \n - File delimiter not found \n - Incorrect file delimiter, should be a tabulation \n - File is malformed\n", 422
            else:
                file_content = get_fileContent(file, '\t')
                if file_content is None:
                    print('here')
                    return "Could not read the file\n", 422
                else:
                    header = file_content.keys()
                    state, notFoundColumn = check_columnName(header, COLUMN_NAMES)
                    if not state:
                        return f"Some column names were not found {','.join(notFoundColumn)}\n", 422
                    else:
                        state, problems = check_fileContent(file_content)
                        if state:
                            return "Correct file\n", 200
                        else:
                            if problems is not None:
                                return 'Incorrect file - File is not compatible with GarganText\n', 422
                            else:
                                return 'Unexpected error in file\n', 422
            