import petl

from gargantools.utils.utils import check_date, check_unacceptedCharactersQuote, check_unacceptedCharactersTab


def check_fileContent(fileContent):
    header = ("Publication Day", "Publication Month", "Publication Year", "Authors", "Title", "Abstract", "Source")
    constraints = [
        dict(
            name = "pub_day", field = "Publication Day", test = int, assertion = lambda x: 0 < x <= 31
        ),
        dict(
            name = "pub_month", field = "Publication Month", test = int, assertion = lambda x : 0 < x <= 12
        ),
        dict(
            name = "pub_year", field = "Publication Year", test = int, assertion = lambda x: x > 0
        ),
        dict(
            name = "date_format", field = ["Publication Day", "Publication Month", "Publication Year"], assertion = lambda row : check_date(row[2], row[1], row[0])
        ),
        dict(
            name = "str_formatQuote", field = "Authors", assertion = lambda x : check_unacceptedCharactersQuote(x)
        ),
        dict(
            name = "str_formatTab", field = "Authors", assertion = lambda x : check_unacceptedCharactersTab(x)
        ),
        dict(
            name = "str_formatQuote", field = "Title", assertion = lambda x : check_unacceptedCharactersQuote(x)
        ),
        dict(
            name = "str_formatTab", field = "Title", assertion = lambda x : check_unacceptedCharactersTab(x)
        ),
        dict(
            name = "str_formatQuote", field = "Abstract", assertion = lambda x : check_unacceptedCharactersQuote(x)
        ),
        dict(
            name = "str_formatTab", field = "Abstract", assertion = lambda x : check_unacceptedCharactersTab(x)
        ),
        dict(
            name = "str_formatQuote", field = "Source", assertion = lambda x : check_unacceptedCharactersQuote(x)
        ),
        dict(
            name = "str_formatTab", field = "Source", assertion = lambda x : check_unacceptedCharactersTab(x)
        )
    ]
    
    dataTable = fileContent.values.tolist()
    dataTable.insert(0, fileContent.columns.to_list())

    problemCells = petl.validate(dataTable, constraints, header)

    if problemCells.len() > 1:
        return False, problemCells
    else:
        return True, None
