import csv
import datetime
import chardet
import pandas as pd

ALLOWED_ENCODING = {"utf-8", "utf-8-sig", "ascii"}


def check_fileExtension(filename, extensions):
    return '.' in filename and filename.rsplit('.', 1)[-1].lower() in extensions

def check_fileEncoding(file):
    
    encoding = None
    content = file.read()
    file.seek(0)
    for decoding in ALLOWED_ENCODING:
        try:
            content.decode(decoding)
            encoding = decoding
            break
        except UnicodeDecodeError:
            None

    if encoding is None:
        encoding = chardet.detect(content)["encoding"]
        print(encoding)
        try:
            content.decode(encoding)
        except UnicodeDecodeError:
            encoding = None
        
    return encoding

def get_fileName(filename):
    return filename.rsplit('.', 1)[:-1][0]

def get_fileDelimiter(file, file_encoding):
    try:
        fileDelimiter = csv.Sniffer().sniff(file.read().decode(file_encoding)).delimiter
    except Exception:
        fileDelimiter = None
        
    file.seek(0)

    return fileDelimiter

def get_fileContent(file, fileDelimiter):
    try:
        fileContent = pd.read_csv(file, sep=fileDelimiter)
    except Exception:
        return None
    
    return fileContent

def check_columnName(list_columnNames, correct_columnNames):
    if len(list_columnNames) > 7:
        return False, []
    else:
        notFound_columnNames = correct_columnNames.copy()

        for colummnName in list_columnNames:
            if colummnName in correct_columnNames:
                notFound_columnNames.remove(colummnName)
                
        if len(notFound_columnNames) != 0:
            return False, notFound_columnNames
        else:
            return True, []

def check_date(y, m, d):
    try:
        datetime.date(y,m,d)
    except Exception:
        return False
    return True

def check_unacceptedCharactersQuote(cell):
    return ('"' in cell.replace('""','WillHaveToChangeThisIfBreak')) == False

def check_unacceptedCharactersTab(cell):
    return ('	' in cell) == False
    