import os
import shutil
import pytest
from gargantools import create_app


TEST_FILES_DIR = os.path.join(os.path.dirname(__file__), 'test_files', 'test_copy')
os.makedirs(TEST_FILES_DIR, exist_ok=True)


@pytest.fixture
def app():

    app = create_app({
        'TESTING': True,
    })

    yield app
    
@pytest.fixture
def test_file_copy(request):
    tfile_name, tfile_dir = request.param
    tfile_path = os.path.join(os.path.dirname(__file__), 'test_files', tfile_dir, tfile_name)

    if not os.path.exists(tfile_path):
        raise FileNotFoundError(f"Test file {tfile_name} not found")
    
    cfile_path = os.path.join(TEST_FILES_DIR, f"copy_{tfile_name}")
    shutil.copy(tfile_path, cfile_path)

    yield cfile_path

    os.remove(cfile_path)

@pytest.fixture
def client(app):
    return app.test_client()

@pytest.fixture
def runner(app):
    return app.test_cli_runner()

def id_files(param):
    file, dir = param
    return f"/{dir}/{file}"
