from io import BytesIO
from itertools import product
from werkzeug.datastructures import FileStorage

import pytest

from tests.conftest import id_files


def test_missingFile(client):
    response = client.post('/terms')
    
    assert response.data == b"Bad request, missing file\n"
    assert response.status_code == 400

@pytest.mark.parametrize("test_file_copy", product(["incorrect.csv", "malformed.csv", "incorrectDelimiter.csv", "incorrectHeader.csv", "incorrectExtension"], ["terms"]), indirect=True, ids=lambda param : id_files(param))
def test_incorrectFile(client, test_file_copy):
    with open(test_file_copy, "rb") as f:
        f_data = BytesIO(f.read())
        file_storage = FileStorage(f_data, filename=test_file_copy)
        response = client.post('/terms', data={'file': file_storage}, content_type='multipart/form-data')

        print(test_file_copy)

        if "incorrect.csv" in test_file_copy:
            assert response.data == b'Incorrect file - File is not compatible with GarganText\n'
        elif "malformed.csv" in test_file_copy:
            assert response.data == b"Error while getting file delimiter.\n Can be the following : \n - File delimiter not found \n - Incorrect file delimiter, should be a tabulation \n - File is malformed\n"
        elif "incorrectDelimiter.csv" in test_file_copy:
            assert response.data == b"Error while getting file delimiter.\n Can be the following : \n - File delimiter not found \n - Incorrect file delimiter, should be a tabulation \n - File is malformed\n"
        elif "incorrectHeader.csv" in test_file_copy:
            assert b"Some column names were not found" in response.data
        elif "incorrectExtension" in test_file_copy:
            assert response.data == b"Incorrect file format or file format not found\n"
            assert response.status_code == 400
        else:
            assert False

        if "incorrectExtension" not in test_file_copy:
            assert response.status_code == 422

@pytest.mark.parametrize("test_file_copy", product(["correct.csv"], ["terms"]), indirect=True, ids=lambda param : id_files(param))
def test_correctFile(client, test_file_copy):
    with open(test_file_copy, "rb") as f:
        f_data = BytesIO(f.read())
        file_storage = FileStorage(f_data, filename=test_file_copy)
        response = client.post('/terms', data={'file': file_storage}, content_type='multipart/form-data')

        assert response.data == b"Correct file\n"
        assert response.status_code == 200
