from io import BytesIO
from itertools import product
import os
import pytest
from gargantools.utils.utils import *
from tests.conftest import id_files


TEST_FILES_DIR = os.path.join(os.path.dirname(__file__), 'test_files')

def test_check_fileExtension():
    list_trueFile = ['a.csv', 'a.tsv', 'a.pdf', 'a.html', 'a.txt', 'a.b.c.csv']
    list_falseFile = ['a', 'a.c']

    for fileName in list_trueFile:
        assert check_fileExtension(fileName, ["csv", "tsv", "pdf", "html", "txt"])
    for fileName in list_falseFile:
        assert not check_fileExtension(fileName, ["csv", "tsv", "pdf", "html", "txt"])

def test_check_fileEncoding():
    file_data = BytesIO("Some data in a random file".encode("utf-8"))
    assert check_fileEncoding(file_data) in ["utf-8", "utf-8-sig", "ascii"]
    
    file_data_ = BytesIO("Some data in a random file".encode("Windows-1252"))
    assert check_fileEncoding(file_data_) is not None

    file_data_ = BytesIO("Some data in a random file".encode("utf-16"))
    assert check_fileEncoding(file_data_) is not None

    # TODO: write test for undetectable file encoding


def test_get_fileName():
    assert get_fileName("afilename.csv") == "afilename"
    assert get_fileName("afile.name.csv") == "afile.name"

@pytest.mark.parametrize("test_file_copy", product(["correct.csv"], ["contexts"]), indirect=True, ids=lambda param : id_files(param))
def test_get_fileDelimiter(test_file_copy):
    with open(test_file_copy, "r") as f:
        f_data = BytesIO(f.read().encode("utf-8"))
        assert get_fileDelimiter(f_data, "utf-8") == "\t"

@pytest.mark.parametrize("test_file_copy", product(["correct.csv"], ["contexts"]), indirect=True, ids=lambda param : id_files(param))
def test_get_fileContent(test_file_copy):
    with open(test_file_copy, "r") as f:
        f_data = BytesIO(f.read().encode("utf-8"))
        assert get_fileContent(f_data, "\t") is not None

def test_check_columnName():
    correct_column = ["Publication Day", "Publication Month", "Publication Year", "Authors", "Title", "Abstract", "Source"]
    list_trueColumnName = ["Publication Day", "Publication Month", "Publication Year", "Authors", "Title", "Abstract", "Source"]
    list_falseColumnName = ["Publication day", "Publication Month", " Year", "Authors", "Title", "Abstract", "Source"]
    list_falseColumnName_more = ["Publication Day", "Publication Month", "Publication Year", "Authors", "Title", "Abstract", "Source", "azerty"]
    list_falseColumnName_less = ["Publication Day", "Publication Year", "Authors", "Title"]

    assert check_columnName(list_trueColumnName, correct_column) == (True, [])
    assert check_columnName(list_falseColumnName, correct_column) == (False, ["Publication Day", "Publication Year"])
    assert check_columnName(list_falseColumnName_more, correct_column) == (False, [])
    assert check_columnName(list_falseColumnName_less, correct_column) == (False, ["Publication Month", "Abstract", "Source"])
    
def test_check_date():
    assert check_date(1,1,1)
    assert not check_date(0,1,1)
    assert not check_date(2000,2,30)
    assert not check_date(2000,13,1)
